@@ -1,39 +1,14 @@
-mtcars2 <- mtcars %>%
-  rownames_to_column(var = "USUBJID")
+mtcars2 <- mtcars %>% rownames_to_column(var = "USUBJID")
 
-t1 <- univar(mtcars2,
-  colvar = "gear",
-  rowvar = "drat",
-  tablebyvar = "am",
-  rowbyvar = "carb"
-)
+t1 <- univar(mtcars2, colvar = "gear", rowvar = "drat", tablebyvar = "am", rowbyvar = "carb")
 
-t2 <- univar(mtcars2,
-  colvar = "gear",
-  rowvar = "wt",
-  tablebyvar = "am",
-  rowbyvar = "carb"
-) %>%
-  mutate(anbr = "hi")
+t2 <- univar(mtcars2, colvar = "gear", rowvar = "wt", tablebyvar = "am", rowbyvar = "carb") %>% mutate(anbr = "hi")
 
-t3 <- univar(mtcars2,
-  colvar = "gear",
-  rowvar = "hp",
-  tablebyvar = "am",
-  rowbyvar = "carb"
-) %>%
-  mutate(anbr = "7")
+t3 <- univar(mtcars2, colvar = "gear", rowvar = "hp", tablebyvar = "am", rowbyvar = "carb") %>% mutate(anbr = "7")
 
-tbl1 <- bind_table(t1, t2, t3,
-  colvar = "gear",
-  rowbyvar = "carb"
-)
+tbl1 <- bind_table(t1, t2, t3, colvar = "gear", rowbyvar = "carb")
 
-tbl2 <- bind_table(t1, t2, t3,
-  colvar = "gear",
-  tablebyvar = "am",
-  rowbyvar = "carb"
-)
+tbl2 <- bind_table(t1, t2, t3, colvar = "gear", tablebyvar = "am", rowbyvar = "carb")
 
 test_that("anbr is assigned correctly", {
   expect_equal(tbl1$anbr, c(rep(1, nrow(t1)), rep(2, nrow(t2)), rep(7, nrow(t3))))
@@ -50,16 +25,9 @@ test_that("bind_table can handle non tidytlg tables", {
     filter(SAFFL == "Y", TRTEMFL == "Y") %>%
     rename(TRT01AN = TRTAN)
 
-  adsl <- cdisc_adsl %>%
-    filter(SAFFL == "Y")
+  adsl <- cdisc_adsl %>% filter(SAFFL == "Y")
 
-  t1 <- adsl %>%
-    freq(
-      colvar = "TRT01AN",
-      rowvar = "SAFFL",
-      rowtext = "Analysis set: Safety",
-      statlist = statlist("n")
-    )
+  t1 <- adsl %>% freq(colvar = "TRT01AN", rowvar = "SAFFL", rowtext = "Analysis set: Safety", statlist = statlist("n"))
 
   t2 <- adae %>%
     freq(
@@ -71,10 +39,7 @@ test_that("bind_table can handle non tidytlg tables", {
       subset = TRTEMFL == "Y"
     )
 
-  t3.1 <- data.frame(
-    label = c("System organ class", "Preferred term"),
-    row_type = "HEADER"
-  )
+  t3_1 <- data.frame(label = c("System organ class", "Preferred term"), row_type = "HEADER")
 
   t3 <- adae %>%
     nested_freq(
@@ -86,9 +51,6 @@ test_that("bind_table can handle non tidytlg tables", {
     )
 
   expect_silent({
-    bind_table(t1, t2, t3.1, t3,
-      colvar = "TRT01AN",
-      rowbyvar = "AEBODSYS"
-    )
+    bind_table(t1, t2, t3_1, t3, colvar = "TRT01AN", rowbyvar = "AEBODSYS")
   })
 })
